# Generated by Django 4.1.3 on 2022-12-07 22:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("preferences", "0003_alter_basepreference_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="basepreference",
            options={
                "ordering": ["namespace", "key"],
                "verbose_name": "Settings",
                "verbose_name_plural": "Settings",
            },
        ),
        migrations.AlterModelOptions(
            name="scopedpreference",
            options={
                "ordering": ["base__namespace", "base__key", "scope"],
                "permissions": [
                    (
                        "change_own_user_scopedpreference",
                        "Can change own user's preferences",
                    ),
                    (
                        "change_own_tenant_scopedpreference",
                        "Can change own tenant's preferences",
                    ),
                    (
                        "change_own_group_scopedpreference",
                        "Can change own groups' preferences",
                    ),
                    (
                        "change_device_scopedpreference",
                        "Can change a device's preferences",
                    ),
                ],
                "verbose_name": "Scoped preferences",
                "verbose_name_plural": "Scoped preferences",
            },
        ),
    ]
