{% extends "layouts/base.html" %}
{% load static i18n alerts %}

{% block stylesheets %}
  <style>
      .bd-placeholder-img {
          font-size: 1.125rem;
          text-anchor: middle;
          -webkit-user-select: none;
          -moz-user-select: none;
          user-select: none;
      }

      @media (min-width: 768px) {
          .bd-placeholder-img-lg {
              font-size: 3.5rem;
          }
      }
  </style>
  <link href="{% static 'css/dashboard.css' %}" rel="stylesheet">

{% endblock stylesheets %}

{% block secondary_menu %}
      <div id="incrementButton" class="btn-group me-2">
        <button type="button" class="btn btn-sm btn-outline-secondary">Export</button>
      </div>
      <div class="dropdown">

        <a href="#" type="button"
           class="btn btn-sm btn-outline-secondary dropdown-toggle"
           data-bs-toggle="dropdown" role="button" aria-expanded="false">
          <i class="bi-calendar"></i>
          This week
        </a>
        <ul class="dropdown-menu">
          <li><a class="dropdown-item" href="#">Action</a></li>
          <li><a class="dropdown-item" href="#">Another action</a></li>
          <li>
            <hr class="dropdown-divider">
          </li>
          <li><a class="dropdown-item" href="#">Separated link</a></li>
        </ul>
      </div>
{% endblock %}

{% block content %}
{##}
{##}
{#  <form>#}
{#    <div class="input-group mb-1 input-group-sm">#}
{#      <span class="input-group-text">Text before</span>#}
{#      <input type="text" class="form-control">#}
{#      <span class="input-group-text">Text after</span>#}
{#      <span class="input-group-text"><i class="bi-search" height="1em"></i></span>#}
{#    </div>#}
{#  </form>#}
{##}
{##}
{#  <h2>Section title</h2>#}
{#  <div class="table-responsive">#}
{#    <table class="table table-striped table-sm">#}
{#      <thead>#}
{#      <tr>#}
{#        <th>#</th>#}
{#        <th>Header</th>#}
{#        <th>Header</th>#}
{#        <th>Header</th>#}
{#        <th>Header</th>#}
{#      </tr>#}
{#      </thead>#}
{#      <tbody>#}
{##}
{#      <tr>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#      </tr>#}
{#      <tr>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#        <td>test</td>#}
{#      </tr>#}
{#      </tbody>#}
{#    </table>#}
{#  </div>#}

{% endblock content %}





