from django.contrib import messages

LEVEL_ICONS = {
    messages.DEBUG: "bug-fill",
    messages.INFO: "info-circle-fill",
    messages.SUCCESS: "check2-circle",
    messages.WARNING: "exclamation-triangle-fill",
    messages.ERROR: "exclamation-square-fill",
}

USERS_GROUP_NAME = "Users"
