<span
    id="badge_{{ component_id }}"
    class="badge rounded-pill bg-danger position-absolute top-0 start-100 translate-middle"
    {% if title %}data-bs-toggle="tooltip" data-bs-placement="top" title="{{ title }}"{% endif %}>
  {{ content }}
</span>