{% extends "layouts/base.html" %}
{% load tz i18n %}

{% block title %}{% trans 'Patient Search' %}{% endblock %}

{% block page_title %}{% trans 'Patient Search' %}{% endblock %}

{% block content %}
{#  {% unicorn "patient-list" %}#}
{% endblock %}