/* Sortable.js handle */
.handle {
    display: inline-block;
    width: 1.5em;
    padding-top: 5px;
    cursor: grab;
}
.handle:after, .handle:before {
    display: block;
    padding-top: 5px;
}
.handle:hover, .handle:hover:before, .handle:hover:after {
    border-color: var(--medux-primary);
}
.handle:active, .handle:active:before, .handle:active:after {
    cursor: grabbing;
}

/* Make icons a bit larger by default */
i.bi {
    font-size:1rem  ;
}

li.nav-item.active,
.list-group-header.sticky-top{
  background-color: rgba(var(--medux-primary-rgb),.16);
}

.btn-toggle::after {
  line-height: 0;
  content: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='currentColor' viewBox='0 0 16 16'%3e%3cpath d='M3.204 5h9.592L8 10.481 3.204 5zm-.753.659 4.796 5.48a1 1 0 0 0 1.506 0l4.796-5.48c.566-.647.106-1.659-.753-1.659H3.204a1 1 0 0 0-.753 1.659z'/%3e%3c/svg%3e");
  transition: transform .35s ease;
  transform-origin: .5em 50%;
  margin-left:auto;
}

.nav-tabs.flex-column .nav-link.active {
    border-right-color: var(--medux-primary);
    border-radius: 5px 0 0 5px;
    border-bottom-color: var(--medux-border-color);
}

.settings-item .nav-tabs.flex-column .nav-link {
    color: var(--medux-primary);
}

/*.btn-toggle::after {*/
/*  line-height: 0;*/
/*  content: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='currentColor' viewBox='0 0 16 16'%3e%3cpath d='M3.204 5h9.592L8 10.481 3.204 5zm-.753.659 4.796 5.48a1 1 0 0 0 1.506 0l4.796-5.48c.566-.647.106-1.659-.753-1.659H3.204a1 1 0 0 0-.753 1.659z'/%3e%3c/svg%3e");*/
/*  transition: transform .35s ease;*/
/*  transform-origin: .5em 50%;*/
/*  margin-left:auto;*/
/*}*/

/*.btn-toggle:hover,*/
/*.btn-toggle:focus {*/
/*  color: rgba(0, 0, 0, .85);*/
/*  background-color: var(--tblr-highlight-bg);*/
/*}*/