{% load i18n %}
<div class="nav-item dropdown d-none d-md-flex me-3">
  <a href="#" class="nav-link px-0" data-bs-toggle="dropdown" tabindex="-1" aria-label="Show notifications">
    <i class="bi bi-bell"></i>
    {% if notifications %}
      <span class="badge bg-red"></span>
    {% endif %}
  </a>
  {% if notifications %}
    <div class="dropdown-menu dropdown-menu-arrow dropdown-menu-end dropdown-menu-card">
      <div class="card">
        <div class="list-group list-group-flush list-group-hoverable">
          {% for notification in notifications %}
            <div class="list-group-item">
              <div class="row align-items-center">
                <div class="col-auto"><span class="status-dot status-dot-animated bg-red d-block"></span></div>
                <div class="col text-truncate">
                  <a href="#" class="text-body d-block">{{ notification.title }}</a>
                  <div class="d-block text-muted text-truncate mt-n1">
                    {{ notification.content }}
                  </div>
                </div>
                <div class="col-auto">
                  <a href="#" class="list-group-item-actions">
                    {# <!-- icon/action -->#}
                  </a>
                </div>
              </div>
            </div>
          {% endfor %}
        </div>
      </div>
    </div>
  {% endif %}
</div>
