<div class="input-group">
    <span class="input-group-text" id="cli-type">Command:
      <span class="badge rounded-pill"></span>
    </span>

    <input type="text"
           name="command"
           class="form-control"
           aria-label="Command"
           aria-describedby="cli-type"
           u:model="command"
           u:keyup.enter="parse"
           autofocus
    >
    <span class="input-group-text">--</span>

{#    <button class="btn btn-danger" u:click.discard="clear">X</button>#}
</div>
