{% extends "layouts/base.html" %}
{% load tz i18n%}

{% block content %}
  <h3>{{ patient.names.first }}{% if patient.title %} <i>{{ patient.title }}</i>{% endif %}</h3> <i class="bi-gender-male"></i>
  <div><i class="bi-phone"></i> {{ patient.phone }}</div>
  <div><i class="bi-email"></i> {{ patient.email }}</div>
{% endblock %}