  <div class="page-header d-print-none">
    <div class="container-xl">
      <div class="row g-2 align-items-center">
        <div class="col">
          <div class="page-pretitle">
            {% block page_pretitle %}
              {{ page_pretitle }}
            {% endblock %}
          </div>
          <h2 class="page-title">
            {% block page_title %}
              {{ page_title }}
            {% endblock %}
          </h2>
        </div>
      </div>
    </div>
  </div>
