<div class="col-12 col-md-auto ms-auto d-print-none">
    <div class="btn-list">
      {% for menu_item in menus.page_menu %}
        {#    <span class="d-none d-sm-inline"> #}
        {#        <a href="#" class="btn"> #}
        {#          <i class='bi bi-... fs-5'></i> Action #}
        {#        </a> #}
        {#    </span> #}
      {% endfor %}
    </div>
</div>