# Generated by Django 4.1.3 on 2022-12-07 22:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0002_create_fixtures"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="avatar",
            field=models.ImageField(null=True, upload_to="user_avatars/"),
        ),
    ]
